6. formfactor (ff) — Jscatter 1.2.0 documentation

# 6. formfactor (ff)

## 6.1. Form Factors

`beaucage` |
`genGuinier` |
`guinier` |
`guinierPorod` |
`guinierPorod3d` |
`gaussianChain` |
`ringPolymer` |
`sphere` |
`sphereCoreShell` |
`sphereFuzzySurface` |
`sphereGaussianCorona` |
`sphereCoreShellGaussianCorona` |
`ellipsoid` |
`disc` |
`multilayer` |
`multiShellSphere` |
`multiShellEllipsoid` |
`multiShellDisc` |
`multiShellCylinder` |
`multilamellarVesicles` |
`cuboid` |
`pearlNecklace` |
`linearPearls` |
`wormlikeChain` |
`teubnerStrey` |
`ellipsoidFilledCylinder` |
`superball` |

## 6.2. Cloud of scatterers

`jscatter.cloudscattering.cloudScattering` |
`jscatter.cloudscattering.orientedCloudScattering` |

## 6.3. Distribution

For multiple distributed parameters use `multiParDistributedAverage()`.

`scatteringFromSizeDistribution` |